pub fn categorize_command(cmd: &str) -> CommandCategoryExpand description
Categorize a single shell command and return category + normalized pattern.
The normalized pattern is the base command + subcommand (e.g. “cargo test”, “npm run build”).
pub fn categorize_command(cmd: &str) -> CommandCategoryCategorize a single shell command and return category + normalized pattern.
The normalized pattern is the base command + subcommand (e.g. “cargo test”, “npm run build”).