pub struct CommandDetail {
pub pattern: String,
pub calls: usize,
pub errors: usize,
}Expand description
Detail for a specific command pattern within a category.
Fields
pattern: Stringcalls: usizeerrors: usizeTrait Implementations
Sourceimpl Clone for CommandDetail
impl Clone for CommandDetail
Sourcefn clone(&self) -> CommandDetail
fn clone(&self) -> CommandDetail
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandDetail
impl Debug for CommandDetail
Sourceimpl Default for CommandDetail
impl Default for CommandDetail
Sourcefn default() -> CommandDetail
fn default() -> CommandDetail
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CommandDetail
impl<'de> Deserialize<'de> for CommandDetail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommandDetail
impl JsonSchema for CommandDetail
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandDetail
impl RefUnwindSafe for CommandDetail
impl Send for CommandDetail
impl Sync for CommandDetail
impl Unpin for CommandDetail
impl UnsafeUnpin for CommandDetail
impl UnwindSafe for CommandDetail