pub struct Correction {
pub turn: usize,
pub text: String,
pub category: CorrectionKind,
}Expand description
An assistant correction or apology.
Fields
turn: usizetext: Stringcategory: CorrectionKindTrait Implementations
Sourceimpl Clone for Correction
impl Clone for Correction
Sourcefn clone(&self) -> Correction
fn clone(&self) -> Correction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Correction
impl Debug for Correction
Sourceimpl<'de> Deserialize<'de> for Correction
impl<'de> Deserialize<'de> for Correction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Correction
impl JsonSchema for Correction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Correction
impl RefUnwindSafe for Correction
impl Send for Correction
impl Sync for Correction
impl Unpin for Correction
impl UnsafeUnpin for Correction
impl UnwindSafe for Correction