pub struct CostBreakdown {
pub model: &'static str,
pub input_cost: f64,
pub output_cost: f64,
pub cache_write_cost: f64,
pub cache_read_cost: f64,
pub total_cost: f64,
pub cache_savings: f64,
}Expand description
Cost breakdown for a session.
Fields
model: &'static strinput_cost: f64output_cost: f64cache_write_cost: f64cache_read_cost: f64total_cost: f64cache_savings: f64Trait Implementations
Sourceimpl Clone for CostBreakdown
impl Clone for CostBreakdown
Sourcefn clone(&self) -> CostBreakdown
fn clone(&self) -> CostBreakdown
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CostBreakdown
impl Debug for CostBreakdown
Sourceimpl Deserialize<'static> for CostBreakdown
impl Deserialize<'static> for CostBreakdown
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'static>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'static>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CostBreakdown
impl JsonSchema for CostBreakdown
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CostBreakdown
impl RefUnwindSafe for CostBreakdown
impl Send for CostBreakdown
impl Sync for CostBreakdown
impl Unpin for CostBreakdown
impl UnsafeUnpin for CostBreakdown
impl UnwindSafe for CostBreakdown