pub struct RetryHotspot {
pub pattern: String,
pub attempts: usize,
pub failures: usize,
pub output_tokens: u64,
pub turn_indices: Vec<usize>,
}Expand description
A command pattern that failed and was retried.
Fields
pattern: Stringattempts: usizefailures: usizeoutput_tokens: u64turn_indices: Vec<usize>Trait Implementations
Sourceimpl Clone for RetryHotspot
impl Clone for RetryHotspot
Sourcefn clone(&self) -> RetryHotspot
fn clone(&self) -> RetryHotspot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RetryHotspot
impl Debug for RetryHotspot
Sourceimpl Default for RetryHotspot
impl Default for RetryHotspot
Sourcefn default() -> RetryHotspot
fn default() -> RetryHotspot
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RetryHotspot
impl<'de> Deserialize<'de> for RetryHotspot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RetryHotspot
impl JsonSchema for RetryHotspot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetryHotspot
impl RefUnwindSafe for RetryHotspot
impl Send for RetryHotspot
impl Sync for RetryHotspot
impl Unpin for RetryHotspot
impl UnsafeUnpin for RetryHotspot
impl UnwindSafe for RetryHotspot